@@ -55,9 +55,9 @@ use strict;
 use XML::Easy::Content 0.001 ();
 use XML::Easy::Element 0.001 ();
 
-our $VERSION = "0.002";
+our $VERSION = "0.003";
 
-use base "Exporter";
+use parent "Exporter";
 our @EXPORT_OK = qw(
 	xml10_read_content_object xml10_read_content
 	xml10_read_element
